@@ -70,7 +70,7 @@ with timeit(): # a handwritten for loop is required under context manager mode
 
 """
 __author__ = 'WEN (github.com/GoodManWEN)'
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 from .utils import *
 from .wrapper import *
@@ -85,5 +85,7 @@ __all__ = (
     'Map',
     'Reduce',
     'Read',
-    'Write'
+    'Write',
+    'ReadB',
+    'WriteB'
 )
